/*
 *  ALSA Output plugin 0.3 for xmms
 *  Copyright (c) by Fumihiko Murata <fmuratap1.tcnet.ne.jp>
 *
 *  Contains code Copyright (C) 1998-1999
 *    Mikael Alm, Olle Hallnas, Thomas Nilsson and 4Front Technologies
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef ALSA_H
#define ALSA_H

#include <gtk/gtk.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <sys/time.h>

#include <sys/asoundlib.h>
#include <linux/asound.h>

#include <fcntl.h>
#include <pthread.h>

#include <stdlib.h>
#include <stdio.h>

#include <xmms/plugin.h>
#include <xmms/configfile.h>

#ifdef ENABLE_NLS
#  include <locale.h>
#    include <libintl.h>
#    define _(String) gettext (String)
#    ifdef gettext_noop
#        define N_(String) gettext_noop (String)
#    else
#        define N_(String) (String)
#    endif
#else
/* Stubs that do something close enough.  */
#    define textdomain(String) (String)
#    define gettext(String) (String)
#    define dgettext(Domain,Message) (Message)
#    define dcgettext(Domain,Message,Type) (Message)
#    define bindtextdomain(Domain,Directory) (Domain)
#    define _(String) (String)
#    define N_(String) (String)
#endif

extern OutputPlugin alsa_op;

typedef struct
{
	int card;
	int mixer_device;
	int pcm_device;
	gint buffer_size;
	gint prebuffer;
	snd_mixer_eid_t eid;
	gint eid_no;
	snd_mixer_element_t mixer_element;
	snd_mixer_element_info_t mixer_info;
	int mixer_range;
	gboolean mixer_auto;
	int mvalue;
} ALSAConfig;

extern ALSAConfig alsa_cfg;

void alsa_init(void);
void alsa_about(void);
void alsa_configure(void);

void alsa_get_volume(int *l,int *r);
void alsa_set_volume(int l,int r);

int alsa_playing(void);
int alsa_free(void);
void alsa_write(void *ptr,int length);
void alsa_close(void);
void alsa_flush(int time);
void alsa_pause(short p);
int alsa_open(AFormat fmt,int rate,int nch);
int alsa_get_output_time(void);
int alsa_get_written_time(void);
void alsa_set_audio_params(void);

void error_win_ok(GtkWidget *widget, gpointer data);
void show_err(char *errmsg);

void configure(void);

#endif
